<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>О Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Благодарности</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Используется Qt %1 (собрано с Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(с) %1-%2 Команда разработчиков Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>Модули ввода:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>Модули вывода:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>Модули визуализации:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>Модули эффектов:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>Общие модули:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Переводчики</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Введите адрес для добавления</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="43"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="50"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="314"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="319"/>
        <source>Filename</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="286"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <location filename="../configdialog.cpp" line="287"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>Дорожка</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="174"/>
        <source>Transports</source>
        <translation>Транспорты</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="184"/>
        <source>Decoders</source>
        <translation>Декодеры</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="194"/>
        <source>Engines</source>
        <translation>Внешние проигрыватели</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="234"/>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>File Dialogs</source>
        <translation>Файловые диалоги</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="254"/>
        <source>User Interfaces</source>
        <translation>Пользовательские интерфейсы</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="288"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="289"/>
        <source>Track number</source>
        <translation>Номер трека</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="290"/>
        <source>Two-digit track number</source>
        <translation>2-x разрядный номер трека</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="294"/>
        <source>Disc number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="298"/>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="308"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;aвтоопределение&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="309"/>
        <source>Brazilian Portuguese</source>
        <translation>бразильский португальский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="310"/>
        <source>Chinese Simplified</source>
        <translation>китайский упрощённый</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="311"/>
        <source>Chinese Traditional</source>
        <translation>китайский традиционный</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Czech</source>
        <translation>чешский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Dutch</source>
        <translation>голландский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>English</source>
        <translation>английский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>French</source>
        <translation>французский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>German</source>
        <translation>немецкий</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>Hebrew</source>
        <translation>иврит</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Hungarian</source>
        <translation>венгерский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Italian</source>
        <translation>итальянский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Japanese</source>
        <translation>японский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Kazakh</source>
        <translation>казахский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Lithuanian</source>
        <translation>литовский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="323"/>
        <source>Polish</source>
        <translation>польский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="324"/>
        <source>Russian</source>
        <translation>русский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="325"/>
        <source>Slovak</source>
        <translation>словацкий</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="326"/>
        <source>Spanish</source>
        <translation>испанский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="327"/>
        <source>Turkish</source>
        <translation>турецкий</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="328"/>
        <source>Ukrainian</source>
        <translation>украинский</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="291"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="296"/>
        <source>File path</source>
        <translation>Путь к файлу</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="292"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Настройки Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="166"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Метаданные</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="135"/>
        <source>Load metadata from files</source>
        <translation>Считывать метаданные из файлов</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="156"/>
        <source>Title format:</source>
        <translation>Формат названия:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="259"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="272"/>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Модули</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="818"/>
        <source>16-bit output</source>
        <translation>16-битный вывод</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="214"/>
        <source>Visualization</source>
        <translation>Визуализация</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="204"/>
        <source>Effects</source>
        <translation>Эффекты</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="757"/>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Directory Scanning Options</source>
        <translation>Опции сканирования директорий</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="182"/>
        <source>Restrict files to:</source>
        <translation>Ограничить выбор файлов до:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Miscellaneous</source>
        <translation>Разное</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="211"/>
        <source>Auto-save playlist when modified</source>
        <translation>Автоматически сохранять список после изменения</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <source>Look and Feel</source>
        <translation>Параметры интерфейса</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Добавлять файлы из командной строки в этот список:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>URL Dialog</source>
        <translation>URL-диалог</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="486"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>Автоматически вставлять URL из буфера обмена</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="627"/>
        <source>Replay Gain</source>
        <translation>Выравнивание громкости (Replay Gain)</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="633"/>
        <source>Replay Gain mode:</source>
        <translation>Режим Replay Gain:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="650"/>
        <source>Preamp:</source>
        <translation>Предусиление:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="682"/>
        <location filename="../forms/configdialog.ui" line="727"/>
        <source>dB</source>
        <translation>дБ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Default gain:</source>
        <translation>Усиление по умолчанию:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Использовать пиковое значение для предотвращения срезания</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="763"/>
        <source>Buffer size:</source>
        <translation>Размер буфера:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="782"/>
        <source>ms</source>
        <translation>мс</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="811"/>
        <source>Use software volume control</source>
        <translation>Использовать программную регулировку громкости</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="410"/>
        <source>Cover Image Retrieve</source>
        <translation>Поиск обложки альбома</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="416"/>
        <source>Use separate image files</source>
        <translation>Использовать отдельные файлы с изображениями</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="426"/>
        <source>Include files:</source>
        <translation>Включить файлы:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="192"/>
        <location filename="../forms/configdialog.ui" line="436"/>
        <source>Exclude files:</source>
        <translation>Исключить файлы:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="448"/>
        <source>Recursive search depth:</source>
        <translation>Глубина рекурсивного поиска:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="373"/>
        <source>Playback</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>Continue playback on startup</source>
        <translation>Продолжить воспроизведение после запуска</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="386"/>
        <source>Determine file type by content</source>
        <translation>Определять тип файла по содержимому</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="525"/>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Enable proxy usage</source>
        <translation>Использовать прокси</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Proxy host name:</source>
        <translation>Прокси сервер:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="557"/>
        <source>Proxy port:</source>
        <translation>Прокси порт:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="570"/>
        <source>Use authentication with proxy</source>
        <translation>Использовать авторизацию на прокси</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="577"/>
        <source>Proxy user name:</source>
        <translation>Имя пользователя прокси:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="590"/>
        <source>Proxy password:</source>
        <translation>Пароль прокси:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="142"/>
        <source>Convert underscores to blanks</source>
        <translation>Преобразовывать подчёркивание в пробел</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="149"/>
        <source>Convert %20 to blanks</source>
        <translation>Преобразовывать %20 в пробел</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="111"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="117"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>Track</source>
        <translation>Дорожка</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="121"/>
        <source>Disc number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation>Открыть директорию, содержащую файл</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation>Общая информация</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Перейти к треку</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="92"/>
        <location filename="../jumptotrackdialog.cpp" line="145"/>
        <source>Queue</source>
        <translation>В очередь</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Перейти к</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="61"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="90"/>
        <location filename="../jumptotrackdialog.cpp" line="143"/>
        <source>Unqueue</source>
        <translation>Снять с очереди</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation>Неподдерживаемый формат списка воспроизведения</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="163"/>
        <location filename="../playlistmanager.cpp" line="351"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="42"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation>Файловый диалог Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>Композитор:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation>Номер диска:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="184"/>
        <location filename="../forms/tageditor.ui" line="222"/>
        <location filename="../forms/tageditor.ui" line="254"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation>Дорожка:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Редактор тегов</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation>Включить выбранный тег в файл</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Редактор шаблонов</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>Номер трека</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>2-х разрядный номер трека</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>Путь к файлу</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="134"/>
        <source>All Supported Bitstreams</source>
        <translation>Все форматы</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <source>Select one or more files to open</source>
        <translation>Выберите один или несколько файлов</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="146"/>
        <source>Choose a directory</source>
        <translation>Выберите директорию</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Playlist Files</source>
        <translation>Файлы списков</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Open Playlist</source>
        <translation>Открыть список</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="184"/>
        <source>Save Playlist</source>
        <translation>Сохранить список</translation>
    </message>
</context>
</TS>
